'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.autocompleteSkinFactory = undefined;

var _slice2 = require('lodash/slice');

var _slice3 = _interopRequireDefault(_slice2);

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _reactCssThemr = require('react-css-themr');

var _identifiers = require('../identifiers');

var _FormFieldSkin = require('./FormFieldSkin');

var _FormFieldSkin2 = _interopRequireDefault(_FormFieldSkin);

var _Autocomplete = require('../../../components/Autocomplete');

var _Autocomplete2 = _interopRequireDefault(_Autocomplete);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * The raw skin for the Autocomplete component.
 *
 * Since the skin uses raw sub-components by default, it exports this
 * factory method to make this configurable from the outside. This
 * is needed to provide components with a default skin (see one level up).
 *
 * @param FormFieldSkin
 * @returns {Component}
 */

var autocompleteSkinFactory = exports.autocompleteSkinFactory = function autocompleteSkinFactory(FormFieldSkin) {
  return function (props) {
    var filteredAndLimitedSuggestions = (0, _slice3.default)(props.filteredWords, 0, props.maxVisibleSuggestions);
    var isFirstOptionHighlighted = props.highlightedOptionIndex === 0 && filteredAndLimitedSuggestions.length;

    var selectedWords = props.selectedWords && props.selectedWords.map(function (selectedWord, index) {
      return _react2.default.createElement(
        'span',
        { className: props.theme.selectedWordBox, key: index },
        _react2.default.createElement(
          'span',
          { className: props.theme.selectedWordValue },
          selectedWord,
          _react2.default.createElement(
            'span',
            {
              className: props.theme.selectedWordRemoveButton,
              onClick: props.component.removeWord.bind(null, index)
            },
            '\xD7'
          )
        )
      );
    });

    // show placeholder only if no maximum selections declared or maximum not reached
    var canMoreWordsBeSelected = props.selectedWords.length < props.maxSelections;
    var placeholder = !props.maxSelections || canMoreWordsBeSelected ? props.placeholder : '';

    // selected words and input for enter new one
    var autocompleteContent = _react2.default.createElement(
      'div',
      { className: props.theme.selectedWords },
      selectedWords,
      _react2.default.createElement('input', {
        className: props.theme.selectWords,
        onKeyDown: props.component.onKeyDown,
        placeholder: placeholder,
        onKeyUp: props.component.clearInvalidChars,
        ref: function ref(element) {
          props.component.registerSkinPart(_Autocomplete2.default.SKIN_PARTS.INPUT, element);
        }
      })
    );

    return _react2.default.createElement(
      'div',
      { ref: function ref(element) {
          return props.component.registerSkinPart(_Autocomplete2.default.SKIN_PARTS.ROOT, element);
        } },
      _react2.default.createElement(FormFieldSkin, _extends({ input: _react2.default.createElement(
          'div',
          {
            className: props.theme.autocompleteWrapper,
            onClick: props.component.handleAutocompleteClick
          },
          _react2.default.createElement(
            'div',
            {
              className: (0, _classnames2.default)([props.theme.autocompleteContent, props.isSuggestionsOpened ? props.theme.opened : null, props.selectedWords.length ? props.theme.hasSelectedWords : null, props.error ? props.theme.errored : null]),
              ref: function ref(element) {
                props.component.registerSkinPart(_Autocomplete2.default.SKIN_PARTS.SUGGESTIONS, element);
              }
            },
            autocompleteContent
          ),
          props.suggestedWords && _react2.default.createElement(
            'ul',
            {
              className: (0, _classnames2.default)([props.theme.suggestionsList, props.isSuggestionsOpened ? props.theme.opened : null, isFirstOptionHighlighted ? props.theme.firstOptionHighlighted : null]),
              style: props.dropdownParams && {
                top: props.dropdownParams.positionY,
                left: props.dropdownParams.positionX,
                width: props.dropdownParams.width
              }
            },
            props.filteredWords.length ? filteredAndLimitedSuggestions.map(function (option, index) {
              return _react2.default.createElement(
                'li',
                {
                  key: index,
                  className: (0, _classnames2.default)([props.theme.suggestionsListItem, index === props.highlightedOptionIndex ? props.theme.highlighted : null]),
                  onMouseEnter: function onMouseEnter() {
                    return props.component.setHighlightedOptionIndex(index);
                  },
                  onClick: function onClick(event) {
                    return props.component.updateSelectedWords(event);
                  }
                },
                option
              );
            }) : _react2.default.createElement(
              'li',
              { className: props.theme.suggestionsListItem },
              'No matching results'
            )
          )
        ) }, props))
    );
  };
};

/**
 * Export the raw version of this component which does not include any styles.
 */
exports.default = (0, _reactCssThemr.themr)(_identifiers.AUTOCOMPLETE)(autocompleteSkinFactory(_FormFieldSkin2.default));
//# sourceMappingURL=AutocompleteSkin.js.map